@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 1;
 
@@ -48,13 +48,13 @@ __END__
 
 =head1 SEE ALSO
 
-L<Tags::Output>,
-L<Tags::Output::PYX>,
-L<Tags::Output::Raw>,
-L<Tags::Process::EntitySubstitute>,
-L<Tags::Process::Id>,
-L<Tags::Process::Validator>,
-L<Tags::Utils::Preserve>.
+=over
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -68,7 +68,8 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION 
 
