@@ -9,7 +9,7 @@ use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -174,7 +174,7 @@ sub _check_arguments {
 
 # Check parameters to rigth values.
 sub _check_params {
-        my $self = shift;
+	my $self = shift;
 
 	# Check to output handler.
 	if (defined $self->{'output_handler'}
@@ -341,7 +341,7 @@ __END__
 =item * C<output_sep>
 
  Output separator.
- Default value is newline.
+ Default value is newline (\n).
 
 =item * C<skip_bad_tags>
 
@@ -384,6 +384,78 @@ __END__
 
 =back
 
+=head1 METHODS TO OVERWRITE
+
+=over 8
+
+=item C<new(%parameters)>
+
+Constructor.
+
+=item C<_check_params()>
+
+ Check parameters to rigth values.
+ Can check constructor parameters.
+ Returns undef.
+
+=item C<_default_parameters()>
+
+ Default parameters.
+ Set list of constructor parameters with default value.
+ e.g.:
+ $self->{'foo'} = 'bar';
+ Returns undef.
+
+=item C<_put_attribute($attr, $value)>
+
+ Attribute callback.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_begin_of_tag($tag)>
+
+ Begin of tag.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_cdata(@cdata)>
+
+ CData.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_comment(@comment)>
+
+ Comment.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_data(@data)>
+
+ Data.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_end_of_tag($tag)>
+
+ End of tag.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_instruction($target, $code)>
+
+ Instruction.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=item C<_put_raw(@raw_data)>
+
+ Raw data.
+ Method can write output to 'flush_code' object parameter as array or scalar.
+ Returns undef.
+
+=back
+
 =head1 ERRORS
 
  new():
@@ -444,10 +516,13 @@ L<Error::Pure>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output::PYX>,
-L<Tags::Output::Raw>,
-L<Tags::Utils>.
+=over
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -461,10 +536,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
