@@ -18,7 +18,7 @@ Readonly::Scalar my $LAST_INDEX => -1;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Resets internal variables.
 sub reset {
@@ -47,7 +47,7 @@ sub reset {
 
 # Check parameters to rigth values.
 sub _check_params {
-        my $self = shift;
+	my $self = shift;
 
 	# Check params from SUPER.
 	$self->SUPER::_check_params();
@@ -84,9 +84,6 @@ sub _default_parameters {
 	# No simple tags.
 	$self->{'no_simple'} = [];
 
-	# Output separator. (Rewrite SUPER value.)
-	$self->{'output_sep'} = $EMPTY_STR;
-
 	# Preserved tags.
 	$self->{'preserved'} = [];
 
@@ -160,7 +157,7 @@ sub _put_attribute {
 	if (defined $attr[1]) {
 		$full_attr .= q{=}.$self->{'attr_delimeter'}.
 			$attr[1].$self->{'attr_delimeter'};
-	}	
+	}
 	push @{$self->{'tmp_code'}}, $SPACE, $full_attr;
 
 	# Reset comment flag.
@@ -425,15 +422,15 @@ __END__
  Example:
  'data_callback' => sub {
          my $data_ar = shift;
-	 foreach my $data (@{$data_ar}) {
+         foreach my $data (@{$data_ar}) {
 
-	         # Some process.
-	         $data =~ s/^\s*//ms;
-	 }
+                 # Some process.
+                 $data =~ s/^\s*//ms;
+         }
          return;
  }
 
-=item * C<no-simple>
+=item * C<no_simple>
 
  Reference to array of tags, that can't by simple.
  Default is [].
@@ -468,7 +465,7 @@ __END__
 
 =item * C<preserved>
 
- TODO
+ List of elements, which content will be preserved.
  Default value is reference to blank array.
 
 =item * C<raw_callback>
@@ -480,12 +477,12 @@ __END__
 
 =item * C<skip_bad_tags>
 
- TODO
+ Skip bad tags.
  Default value is 0.
 
 =item * C<strict_instruction>
 
- TODO
+ Strict instruction.
  Default value is 1.
 
 =item * C<xml>
@@ -565,8 +562,8 @@ __END__
  # Put data.
  $tags->put(
          ['b', 'text'],
-	 ['d', 'data'],
-	 ['e', 'text'],
+         ['d', 'data'],
+         ['e', 'text'],
  );
 
  # Print.
@@ -588,12 +585,12 @@ __END__
  # Object.
  my $tags = Tags::Output::Raw->new(
          'data_callback' => sub {
-	         my $data_ar = shift;
-		 foreach my $data (@{$data_ar}) {
-		         $data = encode_utf8($data);
-		 }
+                 my $data_ar = shift;
+                 foreach my $data (@{$data_ar}) {
+                          $data = encode_utf8($data);
+                 }
                  return;
-	 },
+         },
  );
 
  # Data in characters.
@@ -602,8 +599,8 @@ __END__
  # Put data.
  $tags->put(
          ['b', 'text'],
-	 ['d', $data],
-	 ['e', 'text'],
+         ['d', $data],
+         ['e', 'text'],
  );
 
  # Print.
@@ -621,10 +618,13 @@ L<Tags::Utils::Preserve>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::PYX>,
-L<Tags::Utils>.
+=over
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -638,10 +638,11 @@ L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
