@@ -18,7 +18,7 @@ Readonly::Scalar my $CHAR_CHARS => q{<&\240};
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Encode newline in data to '\n' in output.
 sub encode_newline {
@@ -178,9 +178,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::Raw>.
+=over
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -194,10 +198,11 @@ L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
