@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Scalar my $LAST_INDEX => -1;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -111,7 +111,7 @@ __END__
 
 =head1 NAME
 
- Tags::Utils::Preserve - TODO
+ Tags::Utils::Preserve - Class to check if content in element is preserved?
 
 =head1 SYNOPSIS
 
@@ -137,29 +137,37 @@ __END__
 
 =item * C<preserved>
 
- TODO
+ Preserved tags.
 
 =back
 
 =item C<begin()>
 
- TODO
+ Process for begin of tag.
+ Returns preserved flag in scalar context.
+ Returns preserved flag and previous preserved flag in array context.
 
 =item C<end()>
 
- TODO
+ Process for end of tag.
+ Returns preserved flag in scalar context.
+ Returns preserved flag and previous preserved flag in array context.
 
 =item C<get()>
 
- TODO
+ Get preserved flag.
+ Returns preserved flag in scalar context.
+ Returns preserved flag and previous preserved flag in array context.
 
 =item C<reset()>
 
- TODO
+ Resets.
+ Returns undef.
 
 =item C<save_previous()>
 
- TODO
+ Save previous stay.
+ Returns undef.
 
 =back
 
@@ -224,15 +232,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::ESIS>,
-L<Tags::Output::Indent>,
-L<Tags::Output::LibXML>,
-L<Tags::Output::PYX>,
-L<Tags::Output::Raw>,
-L<Tags::Output::SESIS>,
-L<Tags::Utils>.
+=over
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -246,10 +252,11 @@ L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
